@@ -34,11 +34,11 @@
 #include <ccrtp/crypto/macSkein.h>
 #endif
 
+#include <commoncpp/config.h>
+#include <commoncpp/export.h>
 #include <ccrtp/CryptoContext.h>
 
-#ifdef  CCXX_NAMESPACES
-namespace ost {
-#endif
+NAMESPACE_COMMONCPP
 
 CryptoContext::CryptoContext( uint32 ssrc ):
 ssrc(ssrc),
@@ -195,7 +195,7 @@ void CryptoContext::srtpEncrypt( RTPPacket* rtp, uint64 index, uint32 ssrc )
         return;
     }
 #ifdef SRTP_SUPPORT
-    if (ealg == SrtpEncryptionAESCM) {
+    if (ealg == SrtpEncryptionAESCM || ealg == SrtpEncryptionTWOCM) {
 
         /* Compute the CM IV (refer to chapter 4.1.1 in RFC 3711):
          *
@@ -211,19 +211,19 @@ void CryptoContext::srtpEncrypt( RTPPacket* rtp, uint64 index, uint32 ssrc )
 
         int i;
         for(i = 4; i < 8; i++ ){
-        iv[i] = ( 0xFF & ( ssrc >> ((7-i)*8) ) ) ^ k_s[i];
+            iv[i] = ( 0xFF & ( ssrc >> ((7-i)*8) ) ) ^ k_s[i];
         }
         for(i = 8; i < 14; i++ ){
-        iv[i] = ( 0xFF & (unsigned char)( index >> ((13-i)*8) ) ) ^ k_s[i];
+            iv[i] = ( 0xFF & (unsigned char)( index >> ((13-i)*8) ) ) ^ k_s[i];
         }
         iv[14] = iv[15] = 0;
 
         int32 pad = rtp->isPadded() ? rtp->getPaddingSize() : 0;
-        cipher->ctr_encrypt( const_cast<uint8*>(rtp->getPayload()),
-                  rtp->getPayloadSize()+pad, iv);
+        cipher->ctr_encrypt(const_cast<uint8*>(rtp->getPayload()),
+                            rtp->getPayloadSize()+pad, iv);
     }
 
-    if (ealg == SrtpEncryptionAESF8) {
+    if (ealg == SrtpEncryptionAESF8 || ealg == SrtpEncryptionTWOF8) {
 
         /* Create the F8 IV (refer to chapter 4.1.2.2 in RFC 3711):
          *
@@ -493,9 +493,7 @@ CryptoContext* CryptoContext::newCryptoContextForSSRC(uint32 ssrc, int roc, int6
 #endif
 }
 
-#ifdef  CCXX_NAMESPACES
-}
-#endif
+END_NAMESPACE
 
 /** EMACS **
  * Local variables:
