@@ -48,9 +48,7 @@
 #include <cstdlib>
 #include <climits>
 
-#ifdef  CCXX_NAMESPACES
-namespace ost {
-#endif
+NAMESPACE_COMMONCPP
 
 const uint16 QueueRTCPManager::TIMEOUT_MULTIPLIER = 5;
 const double QueueRTCPManager::RECONSIDERATION_COMPENSATION = 2.718281828 - 1.5;
@@ -575,7 +573,7 @@ bool QueueRTCPManager::onGotSDES(SyncSource& source, RTCPPacket& pkt)
     // 8-bit long, so no ntoh[s|l] is required
     bool cname_found = false;
 
-    ptrdiff_t pointer = reinterpret_cast<unsigned char*>(&pkt) - rtcpRecvBuffer;
+    std::ptrdiff_t pointer = reinterpret_cast<unsigned char*>(&pkt) - rtcpRecvBuffer;
     uint16 i = 0;
     do {
         size_t len = pkt.getLength();
@@ -649,7 +647,7 @@ bool QueueRTCPManager::onGotSDESChunk(SyncSource& source, SDESChunk& chunk, size
             pointer++;
             pointer += (pointer & 0x03); // padding
         } else if ( item->type == SDESItemTypePRIV ) {
-            ptrdiff_t prevpointer = pointer;
+            std::ptrdiff_t prevpointer = pointer;
             uint8 plength = *( &(item->len) + 1 );
             pointer += sizeof(item->type) + sizeof(item->len)  + 1;
 
@@ -1115,9 +1113,7 @@ size_t QueueRTCPManager::sendControlToDestinations(unsigned char* buffer, size_t
     return count;
 }
 
-#ifdef  CCXX_NAMESPACES
-}
-#endif
+END_NAMESPACE
 
 /** EMACS **
  * Local variables:
